Learn R Programming

ghee (version 0.1.0)

gh_collab_list: List current collaborators for a GitHub repo

Description

List current collaborators for a GitHub repo

Usage

gh_collab_list(path, ...)

Arguments

path

GitHub repo path of the form "username/repo". If not provided, will default to current repo.

...

Additional parameters, see https://docs.github.com/en/rest

Value

A data frame that contains the collaborators for the specified repository.

See Also

gh_collab_check() for checking whether a specific user is a collaborator.

Other Collaborations: gh_collab_check(), gh_collab_invite(), gh_collab_pending(), gh_collab_remove(), gh_collab_uninvite()