Check to see if a person was mentioned in a GitHub issue
gh_issue_mention(path, collaborator, ...)GitHub repo path of the form "username/repo". If not provided, will default to current repo.
The collaborator for whom to call this function.
Additional parameters, see https://docs.github.com/en/rest
TRUE if the collaborator was mentioned in any issues; FALSE otherwise
Other Issues:
gh_issue_assign(),
gh_issue_comment(),
gh_issue_list(),
gh_issue_new()